@@ -5,81 +5,40 @@ from pydantic import BaseModel, Field
 from fastapi.encoders import jsonable_encoder
 from .execute import execute, execute_async
 from .gql import GQLException
-from .dgraph_model import DGraphModel
-from .node import Node
-
-
-def parse_filter(filter: DGraphModel) -> str:
-    print(f"{filter=}")
-    return filter.to_gql_str()
-
-
-def parse_nested_q(field_name: str, nested_q: BaseModel):
-    if isinstance(nested_q, DGraphModel):
-        filter_s = parse_filter(nested_q)
-        return f"{field_name}: {{ {filter_s} }}"
-    outer_lst: T.List[str] = []
-    for key, val in nested_q:
-        if val is None:
-            continue
-        # for order, not filter
-        if not isinstance(val, BaseModel):
-            outer_lst.append(f"{key}: {val}")
-            continue
-        val: BaseModel
-        inner_lst: T.List[str] = []
-        for inner_key, inner_val in val.dict(exclude_none=True).items():
-            inner_str = f"{inner_key}: {json.dumps(jsonable_encoder(inner_val))}"
-            inner_lst.append(inner_str)
-        outer_lst.append(f'{key}: {{ {",".join(inner_lst)} }}')
-    return f'{field_name}: {{ {",".join(outer_lst)} }}'
-
-
-class Params(BaseModel):
-    def to_str(self) -> str:
-        field_names = self.dict(exclude_none=True).keys()
-        inner_params: T.List[str] = []
-        for field_name in field_names:
-            val = getattr(self, field_name)
-            if isinstance(val, BaseModel):
-                inner_params.append(parse_nested_q(field_name=field_name, nested_q=val))
-            else:
-                inner_params.append(
-                    f"{field_name}: {json.dumps(jsonable_encoder(val))}"
-                )
-        if inner_params:
-            return f'({",".join(inner_params)})'
-        return ""
+from .node import Node, Params
 
 
 NodeType = T.TypeVar("NodeType", bound=Node)
+ResolverType = T.TypeVar("ResolverType")
+
+
 GetParamsType = T.TypeVar("GetParamsType", bound=Params)
 QueryParamsType = T.TypeVar("QueryParamsType", bound=Params)
 EdgesType = T.TypeVar("EdgesType", bound=BaseModel)
 
 
-class Resolver(
-    BaseModel, T.Generic[NodeType, GetParamsType, QueryParamsType, EdgesType]
-):
-    def __init__(
-        self,
-        query_params: T.Optional[QueryParamsType] = None,
-        edges: T.Optional[EdgesType] = None,
-    ):
-        get_params = self.model.GQL.GetParams()
-        query_params = query_params or self.model.GQL.QueryParams()
-        edges = edges or self.model.GQL.Edges()
-        super().__init__(get_params=get_params, query_params=query_params, edges=edges)
+class Resolver(BaseModel):
+    node: T.Type[NodeType]
 
-    model: T.ClassVar[T.Type[NodeType]]
+    edges: EdgesType
+    get_params: GetParamsType
+    query_params: QueryParamsType
 
-    edges: EdgesType = Field(default_factory=Node.GQL.Edges)
-    get_params: GetParamsType = Field(default_factory=Node.GQL.GetParams)
-    query_params: QueryParamsType = Field(default_factory=Node.GQL.QueryParams)
+    @classmethod
+    def from_node(
+        cls: T.Type[ResolverType], node_cls: T.Type[NodeType]
+    ) -> ResolverType:
+        cls(
+            node=node_cls,
+            edges=node_cls.GQL.Edges(),
+            get_params=node_cls.GQL.GetParams(),
+            query_params=node_cls.GQL.QueryParams(),
+        )
+        return cls
 
     def gql_fields_str(self) -> str:
         """This does not include the top level..."""
-        fields = [*self.model.__fields__.keys(), "__typename"]
+        fields = [*self.node.__fields__.keys(), "__typename"]
         for resolver_name in self.edges.__fields__.keys():
             resolver: T.Optional[Resolver] = getattr(self.edges, resolver_name, None)
             if resolver:
@@ -108,11 +67,11 @@ class Resolver(
 
     @classmethod
     def get_query_name(cls) -> str:
-        return f"get{cls.model.GQL.typename}"
+        return f"get{cls.node.GQL.typename}"
 
     @classmethod
     def query_query_name(cls) -> str:
-        return f"query{cls.model.GQL.typename}"
+        return f"query{cls.node.GQL.typename}"
 
     def make_query_query_str(self) -> str:
         s = f"{{ {self.query_query_name()}{self.params_and_fields()} }}"
@@ -132,7 +91,7 @@ class Resolver(
         return [self.parse_obj_nested(d) for d in lst]
 
     def parse_obj_nested(self, gql_d: dict) -> NodeType:
-        node: NodeType = self.model.parse_obj(gql_d)
+        node: NodeType = self.node.parse_obj(gql_d)
         other_fields = set(gql_d.keys()) - set(node.__fields__.keys()) - {"__typename"}
         for field in other_fields:
             resolver = getattr(self.edges, field, None)
@@ -164,6 +123,7 @@ class Resolver(
             return self.parse_obj_nested(obj)
         return None
 
+    """
     def get(self, get_params: GetParamsType) -> T.Optional[NodeType]:
         return self._get(kwargs_d=get_params.dict())
 
@@ -175,13 +135,14 @@ class Resolver(
         if not node:
             raise GQLException(f"Node with {get_params=} was None")
         return node
+    """
 
     @staticmethod
     def resolvers_by_typename() -> T.Dict[str, T.Type[Resolver]]:
         d = {}
         subs = Resolver.__subclasses__()
         for sub in subs:
-            typename = sub.model.GQL.typename
+            typename = sub.node.GQL.typename
             if typename in d:
                 raise GQLException(
                     f"Two Resolvers share the typename {typename}: ({sub.__name__}, {d[typename].__name__})"
